@@ -1,4 +1,6 @@
 # 국토교통부(molit) Open API 통합
+from PublicDataReader.PublicDataPortal.molit import TransactionPrice, BuildingLedger
+# (Deprecated)
 from PublicDataReader.PublicDataPortal.molit import Transaction, Building
 
 # 소상공인 진흥공단(semas) Open API 통합
